@@ -254,9 +254,7 @@ plot_incremental <- function(.data) {
 #' @export
 plot_incremental.ramp <- function(.data) {
   ## check if ggforce is installed
-  if(length(find.package(package = "ggforce", quiet = TRUE)) == 0) {
-    stop("You need to install the ggforce package to use this function.", call. = FALSE)
-  }
+  rlang::check_installed("ggforce")
 
   ## get time column
   time_column <- attr(.data, "time_column")
